//
//  DREncodingPreset.h
//  DeepRecorder
//
//  Created by mmivi on 06.04.09.
//  Copyright 2009 DeepIT. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <QuickTime/QuickTime.h>

#define DR_EPRESET_NAME_KEY @"Name"
#define DR_EPRESET_SOUNDSETTINGS_KEY @"SoundSettings"
#define DR_EPRESET_VIDEOSETTINGS_KEY @"VideoSettings"
#define DR_EPRESET_INCAUDIO_KEY @"IncludeAudio"
#define DR_EPRESET_INCVIDEO_KEY @"IncludeVideo"
#define DR_EPRESET_INCCURSOR_KEY @"IncludeCursor"
#define DR_EPRESET_SIZE_KEY @"Size"
#define DR_EPRESET_SCALE_KEY @"Scale"
#define DR_EPRESET_SCALEMODE_KEY @"ScaleMode"
#define DR_EPRESET_MCLICK_KEY @"ShowMouseClicks"
#define DR_EPRESET_SHOWKEYS_KEY @"ShowKeysPressed"
#define DR_EPRESET_INCSYSAU_KEY @"IncludeSystemAudio"
#define DR_EPRESET_INCEXTAU_KEY @"IncludeExternalAudio"

typedef enum
{
	DRPresetByScale,
	DRPresetBySize
} DRPresetScaleMode;

@interface DREncodingPreset : NSObject {
	NSString * _name;
	NSData * _soundSettings, * _videoSetting;
	NSSize _videoDimensions;
	double _videoScale;
	DRPresetScaleMode _videoScaleMode;
	
	BOOL _includeAudioTrack, _includeVideoTrack, _includeCursorTrack, _showMouseClicks, _showKeysPressed;
	BOOL _includeSystemAudio, _includeExternalAudio;
}

- (id) initWithName: (NSString *)presetName;
- (id) initWithDictRepresentation: (NSDictionary *)dict;

+ (id)presetWithName: (NSString *)presetName;
+ (id)presetWithDictRepresentation: (NSDictionary *)dict;

+ (QTAtomContainer)requestUserSettingsForVideo: (QTAtomContainer)defaultSettings;
+ (QTAtomContainer)requestUserSettingsForAudio: (QTAtomContainer)defaultSettings;

- (void) dealloc;

- (void)setName: (NSString *)newName;
- (NSString *)name;

- (void)setSoundSettings: (QTAtomContainer)soundSettings;
- (QTAtomContainer)soundSettings;

- (void)setVideoSettings: (QTAtomContainer)videoSettings;
- (QTAtomContainer)videoSettings;

- (NSDictionary *)dictRepresentation;

- (void)setIncludesAudioTrack: (BOOL)flag;
- (void)setIncludesVideoTrack: (BOOL)flag;
- (void)setIncludesCursorTrack: (BOOL)flag;
- (BOOL)includesAudioTrack;
- (BOOL)includesVideoTrack;
- (BOOL)includesCursorTrack;
- (void)setIncludesSystemAudio:(BOOL)flag;
- (BOOL)includesSystemAudio;
- (void)setIncludesExternalAudio:(BOOL)flag;
- (BOOL)includesExternalAudio;

- (void)setShowsMouseClicks:(BOOL)flag;
- (BOOL)showsMouseClicks;

- (void)setShowsKeysPressed:(BOOL)flag;
- (BOOL)showsKeysPressed;

- (void)setVideoDimensions: (NSSize)size;
- (NSSize)videoDimensions;

- (void)setVideoScale: (double)scale;
- (double)videoScale;

- (void)setVideoScaleMode: (DRPresetScaleMode)mode;
- (DRPresetScaleMode)videoScaleMode;

@end
